@@ -13,12 +13,7 @@ def private(thing: ModuleAware) -> ModuleAware:
     :return: The original `thing` object.
     :raises ValueError: When this function finds a non-list __all__ attribute.
     """
-    mdict = (
-        # The function call syntax.
-        sys._getframe(1).f_globals
-        if thing is None
-        # The decorator syntax.
-        else sys.modules[thing.__module__].__dict__)
+    mdict = sys.modules[thing.__module__].__dict__
     dunder_all = mdict.setdefault('__all__', [])
     if not isinstance(dunder_all, list):
         raise ValueError(f'__all__ must be a list not: {type(dunder_all)}')
